
.. automodule:: bci_framework.framework
   :members:
   :no-undoc-members:
   :no-show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bci_framework.framework.editor
   bci_framework.framework.environments
   bci_framework.framework.qtgui
   bci_framework.framework.widgets

Submodules
----------

.. toctree::
   :maxdepth: 4

   bci_framework.framework.config_manager
   bci_framework.framework.configuration
   bci_framework.framework.core
   bci_framework.framework.dialogs
   bci_framework.framework.extensions_handler
   bci_framework.framework.nbstreamreader
   bci_framework.framework.subprocess_handler
